@@ -14,7 +14,7 @@ use App::Sqitch::Types qw(Str Int Sqitch Plan Bool HashRef URI Maybe Target);
 use namespace::autoclean;
 use constant registry_release => '1.1';
 
-our $VERSION = 'v1.0.0'; # VERSION
+our $VERSION = 'v1.1.0'; # VERSION
 
 has sqitch => (
     is       => 'ro',
@@ -373,15 +373,8 @@ sub verify {
     }
 
     # Figure out where to start and end relative to the plan.
-    my $from_idx = defined $from
-        ? $self->_trim_to('verify', $from, \@changes)
-        : 0;
-
-    my $to_idx = defined $to ? $self->_trim_to('verify', $to, \@changes, 1) : do {
-        if (my $id = $self->latest_change_id) {
-            $plan->index_of( $id );
-        }
-    } // $plan->count - 1;
+    my $from_idx = $self->_from_idx('verify', $from, \@changes);
+    my $to_idx = $self->_to_idx('verify', $to, \@changes);
 
     # Run the verify tests.
     if ( my $count = $self->_verify_changes($from_idx, $to_idx, !$to, @changes) ) {
@@ -404,6 +397,22 @@ sub verify {
     return $self;
 }
 
+sub _from_idx {
+    my ( $self, $ident, $from, $changes) = @_;
+    return 0 unless defined $from;
+    return $self->_trim_to($ident, $from, $changes)
+}
+
+sub _to_idx {
+    my ( $self, $ident, $to, $changes) = @_;
+    my $plan = $self->plan;
+    return $self->_trim_to($ident, $to, $changes, 1) if defined $to;
+    if (my $id = $self->latest_change_id) {
+        return $plan->index_of( $id ) // $plan->count - 1;
+    }
+    return $plan->count - 1;
+}
+
 sub _trim_to {
     my ( $self, $ident, $key, $changes, $pop ) = @_;
     my $sqitch = $self->sqitch;
@@ -1094,6 +1103,80 @@ sub upgrade_registry {
     return $self;
 }
 
+sub _find_planned_deployed_divergence_idx {
+    my ($self, $from_idx, @deployed_changes) = @_;
+    my $i = -1;
+    my $plan = $self->plan;
+
+    foreach my $change (@deployed_changes) {
+        $i++;
+        return $i if $i + $from_idx >= $plan->count
+            || $change->script_hash ne $plan->change_at($i + $from_idx)->script_hash;
+    }
+
+    return -1;
+}
+
+sub planned_deployed_common_ancestor_id {
+    my ( $self ) = @_;
+    my @deployed_changes = $self->_load_changes( $self->deployed_changes );
+    my $divergent_idx = $self->_find_planned_deployed_divergence_idx(0, @deployed_changes);
+
+    return $deployed_changes[-1]->id if $divergent_idx == -1;
+    return undef if $divergent_idx == 0;
+    return $deployed_changes[$divergent_idx - 1]->id;
+}
+
+sub check {
+    my ( $self, $from, $to ) = @_;
+    $self->_check_registry;
+    my $sqitch   = $self->sqitch;
+    my $plan     = $self->plan;
+    my @deployed_changes  = $self->_load_changes( $self->deployed_changes );
+    my $num_failed = 0;
+
+    $sqitch->info(__x(
+        'Checking {destination}',
+        destination => $self->destination,
+    ));
+
+    if (!@deployed_changes) {
+        my $msg = $plan->count
+            ? __ 'No changes deployed'
+            : __ 'Nothing to check (no planned or deployed changes)';
+        $sqitch->info($msg);
+        return $self;
+    }
+
+    # Figure out where to start and end relative to the plan.
+    my $from_idx = $self->_from_idx('check', $from, \@deployed_changes);
+    $self->_to_idx('check', $to, \@deployed_changes);
+
+    my $divergent_change_idx = $self->_find_planned_deployed_divergence_idx($from_idx, @deployed_changes);
+    if ($divergent_change_idx != -1) {
+        $num_failed++;
+        $sqitch->emit(__x(
+            'Script signatures diverge at change {change}',
+            change => $deployed_changes[$divergent_change_idx]->format_name_with_tags,
+        ));
+    }
+
+    hurl {
+        ident => 'check',
+        message => __nx(
+            'Failed one check',
+            'Failed {count} checks',
+            $num_failed,
+            count => $num_failed,
+        ),
+        exitval => $num_failed,
+    } if $num_failed;
+
+    $sqitch->emit(__ 'Check successful');
+
+    return $self;
+}
+
 sub initialized {
     my $class = ref $_[0] || $_[0];
     hurl "$class has not implemented initialized()";
@@ -1604,6 +1687,23 @@ Changes without verify scripts will emit a warning, but not constitute a
 failure. If there are any failures, an exception will be thrown once all
 verifications have completed.
 
+=head3 C<check>
+
+  $engine->check;
+  $engine->check( $from );
+  $engine->check( $from, $to );
+  $engine->check( undef, $to );
+
+Compares the state of the working directory and the database by comparing the
+SHA1 hashes of the deploy scripts. Fails and reports divergence for all
+changes with non-matching hashes, indicating that the project deploy scripts
+differ from the scripts that were used to deploy to the database.
+
+Pass in change identifiers, as described in L<sqitchchanges>, to limit the
+changes to check. For each change, information will be emitted if the SHA1
+digest of the current deploy script does not match its SHA1 digest at the
+time of deployment.
+
 =head3 C<check_deploy_dependencies>
 
   $engine->check_deploy_dependencies;
@@ -2420,6 +2520,15 @@ number of changes before or after the change, as appropriate.
 Like C<change_offset_from_id()> but returns the change ID rather than the
 change object.
 
+=head3 C<planned_deployed_common_ancestor_id>
+
+  my $change_id = $engine->planned_deployed_common_ancestor_id;
+
+Compares the SHA1 hashes of the deploy scripts to their values at the time of
+deployment to the database and returns the latest change ID prior to any
+changes for which the values diverge. Used for the C<--modified> option to
+the C<revert> and C<rebase> commands.
+
 =head3 C<registry_version>
 
 Should return the current version of the target's registry.
@@ -2440,7 +2549,7 @@ David E. Wheeler <david@justatheory.com>
 
 =head1 License
 
-Copyright (c) 2012-2018 iovation Inc.
+Copyright (c) 2012-2020 iovation Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
