@@ -1,5 +1,5 @@
 /*
- * Sqitch database deployment metadata v1.0.;
+ * Sqitch database deployment metadata v1.1.;
  */
 
 /*
@@ -43,7 +43,7 @@ COMMENT ON COLUMN projects.creator_email  IS 'Email address of the user who adde
 
 CREATE TABLE changes (
     change_id       VARCHAR(40)   NOT NULL PRIMARY KEY,
-    script_hash     VARCHAR(40)            UNIQUE,
+    script_hash     VARCHAR(40),
     change          VARCHAR(255)  NOT NULL,
     project         VARCHAR(255)  NOT NULL REFERENCES projects(project)
                                        ON UPDATE CASCADE,
@@ -53,7 +53,8 @@ CREATE TABLE changes (
     committer_email VARCHAR(255)  NOT NULL,
     planned_at      TIMESTAMP     NOT NULL,
     planner_name    VARCHAR(255)  NOT NULL,
-    planner_email   VARCHAR(255)  NOT NULL
+    planner_email   VARCHAR(255)  NOT NULL,
+    UNIQUE(project, script_hash)
 );
 
 COMMENT ON TABLE  changes                 IS 'Tracks the changes currently deployed to the database.';
@@ -75,9 +76,9 @@ CREATE TABLE tags (
     tag_id          CHAR(40)      NOT NULL PRIMARY KEY,
     tag             VARCHAR(250)  NOT NULL,
     project         VARCHAR(255)  NOT NULL REFERENCES projects(project)
-                                       ON UPDATE CASCADE,
+                                        ON UPDATE CASCADE,
     change_id       CHAR(40)      NOT NULL REFERENCES changes(change_id)
-                                       ON UPDATE CASCADE,
+                                        ON UPDATE CASCADE,
     note            BLOB SUB_TYPE TEXT DEFAULT '' NOT NULL,
     committed_at    TIMESTAMP     DEFAULT CURRENT_TIMESTAMP NOT NULL,
     committer_name  VARCHAR(512)  NOT NULL,
@@ -105,13 +106,13 @@ COMMENT ON COLUMN tags.planner_email   IS 'Email address of the user who planned
 
 CREATE TABLE dependencies (
     change_id       CHAR(40)      NOT NULL REFERENCES changes(change_id)
-                                       ON UPDATE CASCADE ON DELETE CASCADE,
+                                        ON UPDATE CASCADE ON DELETE CASCADE,
     type            VARCHAR(8)    NOT NULL,
     dependency      VARCHAR(512)  NOT NULL,
     dependency_id   CHAR(40)      REFERENCES changes(change_id)
-                                       ON UPDATE CASCADE CHECK (
-                          (type = 'require'  AND dependency_id IS NOT NULL)
-                       OR (type = 'conflict' AND dependency_id IS NULL)
+                                        ON UPDATE CASCADE CONSTRAINT dependencies_check CHECK (
+           (type = 'require'  AND dependency_id IS NOT NULL)
+        OR (type = 'conflict' AND dependency_id IS NULL)
     ),
     PRIMARY KEY (change_id, dependency)
 );
@@ -126,11 +127,13 @@ COMMENT ON COLUMN dependencies.dependency_id IS 'Change ID the dependency resolv
 
 CREATE TABLE events (
     event           VARCHAR(6)    NOT NULL
-                    CONSTRAINT check_event_type CHECK (event IN ('deploy', 'revert', 'fail', 'merge')),
+    CONSTRAINT events_event_check CHECK (
+        event IN ('deploy', 'revert', 'fail', 'merge')
+    ),
     change_id       CHAR(40)      NOT NULL,
     change          VARCHAR(512)  NOT NULL,
     project         VARCHAR(255)  NOT NULL REFERENCES projects(project)
-                                       ON UPDATE CASCADE,
+                                        ON UPDATE CASCADE,
     note            BLOB SUB_TYPE TEXT DEFAULT '' NOT NULL,
     requires        BLOB SUB_TYPE TEXT DEFAULT '' NOT NULL,
     conflicts       BLOB SUB_TYPE TEXT DEFAULT '' NOT NULL,
